pub struct DataTransferService { /* private fields */ }Expand description
Implements a client for the Network Connectivity API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = DataTransferService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_multicloud_data_transfer_configs()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
DataTransferService is the service for the Data Transfer API.
Configuration
To configure DataTransferService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://networkconnectivity.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
DataTransferService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap DataTransferService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl DataTransferService
impl DataTransferService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for DataTransferService.
let client = DataTransferService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: DataTransferService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: DataTransferService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_multicloud_data_transfer_configs(
&self,
) -> ListMulticloudDataTransferConfigs
pub fn list_multicloud_data_transfer_configs( &self, ) -> ListMulticloudDataTransferConfigs
Lists the MulticloudDataTransferConfig resources in a specified project
and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService, parent: &str
) -> Result<()> {
let mut list = client.list_multicloud_data_transfer_configs()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_multicloud_data_transfer_config(
&self,
) -> GetMulticloudDataTransferConfig
pub fn get_multicloud_data_transfer_config( &self, ) -> GetMulticloudDataTransferConfig
Gets the details of a MulticloudDataTransferConfig resource.
Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService, name: &str
) -> Result<()> {
let response = client.get_multicloud_data_transfer_config()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_multicloud_data_transfer_config(
&self,
) -> CreateMulticloudDataTransferConfig
pub fn create_multicloud_data_transfer_config( &self, ) -> CreateMulticloudDataTransferConfig
Creates a MulticloudDataTransferConfig resource in a specified project
and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networkconnectivity_v1::model::MulticloudDataTransferConfig;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService, parent: &str
) -> Result<()> {
let response = client.create_multicloud_data_transfer_config()
.set_parent(parent)
.set_multicloud_data_transfer_config(
MulticloudDataTransferConfig::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_multicloud_data_transfer_config(
&self,
) -> UpdateMulticloudDataTransferConfig
pub fn update_multicloud_data_transfer_config( &self, ) -> UpdateMulticloudDataTransferConfig
Updates a MulticloudDataTransferConfig resource in a specified project
and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networkconnectivity_v1::model::MulticloudDataTransferConfig;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService, name: &str
) -> Result<()> {
let response = client.update_multicloud_data_transfer_config()
.set_multicloud_data_transfer_config(
MulticloudDataTransferConfig::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_multicloud_data_transfer_config(
&self,
) -> DeleteMulticloudDataTransferConfig
pub fn delete_multicloud_data_transfer_config( &self, ) -> DeleteMulticloudDataTransferConfig
Deletes a MulticloudDataTransferConfig resource.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService, name: &str
) -> Result<()> {
client.delete_multicloud_data_transfer_config()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_destinations(&self) -> ListDestinations
pub fn list_destinations(&self) -> ListDestinations
Lists the Destination resources in a specified project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService, parent: &str
) -> Result<()> {
let mut list = client.list_destinations()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_destination(&self) -> GetDestination
pub fn get_destination(&self) -> GetDestination
Gets the details of a Destination resource.
Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService, name: &str
) -> Result<()> {
let response = client.get_destination()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_destination(&self) -> CreateDestination
pub fn create_destination(&self) -> CreateDestination
Creates a Destination resource in a specified project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networkconnectivity_v1::model::Destination;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService, parent: &str
) -> Result<()> {
let response = client.create_destination()
.set_parent(parent)
.set_destination_id("destination_id_value")
.set_destination(
Destination::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_destination(&self) -> UpdateDestination
pub fn update_destination(&self) -> UpdateDestination
Updates a Destination resource in a specified project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networkconnectivity_v1::model::Destination;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService, name: &str
) -> Result<()> {
let response = client.update_destination()
.set_destination(
Destination::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_destination(&self) -> DeleteDestination
pub fn delete_destination(&self) -> DeleteDestination
Deletes a Destination resource.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService, name: &str
) -> Result<()> {
client.delete_destination()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn get_multicloud_data_transfer_supported_service(
&self,
) -> GetMulticloudDataTransferSupportedService
pub fn get_multicloud_data_transfer_supported_service( &self, ) -> GetMulticloudDataTransferSupportedService
Gets the details of a service that is supported for Data Transfer Essentials.
Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService, name: &str
) -> Result<()> {
let response = client.get_multicloud_data_transfer_supported_service()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_multicloud_data_transfer_supported_services(
&self,
) -> ListMulticloudDataTransferSupportedServices
pub fn list_multicloud_data_transfer_supported_services( &self, ) -> ListMulticloudDataTransferSupportedServices
Lists the services in the project for a region that are supported for Data Transfer Essentials.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService, parent: &str
) -> Result<()> {
let mut list = client.list_multicloud_data_transfer_supported_services()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
client: &DataTransferService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for DataTransferService
impl Clone for DataTransferService
Sourcefn clone(&self) -> DataTransferService
fn clone(&self) -> DataTransferService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more