HubService

Struct HubService 

pub struct HubService { /* private fields */ }
Implements a client for the Network Connectivity API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = HubService::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_hubs()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

Network Connectivity Center is a hub-and-spoke abstraction for network connectivity management in Google Cloud. It reduces operational complexity through a simple, centralized connectivity management model.

Configuration

To configure HubService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://networkconnectivity.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

HubService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap HubService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl HubService

pub fn builder() -> ClientBuilder

Returns a builder for HubService.

let client = HubService::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: HubService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn list_hubs(&self) -> ListHubs

Lists the Network Connectivity Center hubs associated with a given project.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, parent: &str
) -> Result<()> {
    let mut list = client.list_hubs()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_hub(&self) -> GetHub

Gets details about a Network Connectivity Center hub.

Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, name: &str
) -> Result<()> {
    let response = client.get_hub()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_hub(&self) -> CreateHub

Creates a new Network Connectivity Center hub in the specified project.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networkconnectivity_v1::model::Hub;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, parent: &str
) -> Result<()> {
    let response = client.create_hub()
        .set_parent(parent)
        .set_hub_id("hub_id_value")
        .set_hub(
            Hub::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_hub(&self) -> UpdateHub

Updates the description and/or labels of a Network Connectivity Center hub.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networkconnectivity_v1::model::Hub;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, name: &str
) -> Result<()> {
    let response = client.update_hub()
        .set_hub(
            Hub::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_hub(&self) -> DeleteHub

Deletes a Network Connectivity Center hub.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, name: &str
) -> Result<()> {
    client.delete_hub()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn list_hub_spokes(&self) -> ListHubSpokes

Lists the Network Connectivity Center spokes associated with a specified hub and location. The list includes both spokes that are attached to the hub and spokes that have been proposed but not yet accepted.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService
) -> Result<()> {
    let mut list = client.list_hub_spokes()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn query_hub_status(&self) -> QueryHubStatus

Query the Private Service Connect propagation status of a Network Connectivity Center hub.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService
) -> Result<()> {
    let mut list = client.query_hub_status()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn list_spokes(&self) -> ListSpokes

Lists the Network Connectivity Center spokes in a specified project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, parent: &str
) -> Result<()> {
    let mut list = client.list_spokes()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_spoke(&self) -> GetSpoke

Gets details about a Network Connectivity Center spoke.

Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, name: &str
) -> Result<()> {
    let response = client.get_spoke()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_spoke(&self) -> CreateSpoke

Creates a Network Connectivity Center spoke.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networkconnectivity_v1::model::Spoke;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, parent: &str
) -> Result<()> {
    let response = client.create_spoke()
        .set_parent(parent)
        .set_spoke_id("spoke_id_value")
        .set_spoke(
            Spoke::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_spoke(&self) -> UpdateSpoke

Updates the parameters of a Network Connectivity Center spoke.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networkconnectivity_v1::model::Spoke;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, name: &str
) -> Result<()> {
    let response = client.update_spoke()
        .set_spoke(
            Spoke::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn reject_hub_spoke(&self) -> RejectHubSpoke

Rejects a Network Connectivity Center spoke from being attached to a hub. If the spoke was previously in the ACTIVE state, it transitions to the INACTIVE state and is no longer able to connect to other spokes that are attached to the hub.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService
) -> Result<()> {
    let response = client.reject_hub_spoke()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn accept_hub_spoke(&self) -> AcceptHubSpoke

Accepts a proposal to attach a Network Connectivity Center spoke to a hub.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService
) -> Result<()> {
    let response = client.accept_hub_spoke()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn accept_spoke_update(&self) -> AcceptSpokeUpdate

Accepts a proposal to update a Network Connectivity Center spoke in a hub.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService
) -> Result<()> {
    let response = client.accept_spoke_update()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn reject_spoke_update(&self) -> RejectSpokeUpdate

Rejects a proposal to update a Network Connectivity Center spoke in a hub.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService
) -> Result<()> {
    let response = client.reject_spoke_update()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_spoke(&self) -> DeleteSpoke

Deletes a Network Connectivity Center spoke.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, name: &str
) -> Result<()> {
    client.delete_spoke()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn get_route_table(&self) -> GetRouteTable

Gets details about a Network Connectivity Center route table.

Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, name: &str
) -> Result<()> {
    let response = client.get_route_table()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_route(&self) -> GetRoute

Gets details about the specified route.

Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, name: &str
) -> Result<()> {
    let response = client.get_route()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_routes(&self) -> ListRoutes

Lists routes in a given route table.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, parent: &str
) -> Result<()> {
    let mut list = client.list_routes()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn list_route_tables(&self) -> ListRouteTables

Lists route tables in a given hub.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, parent: &str
) -> Result<()> {
    let mut list = client.list_route_tables()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_group(&self) -> GetGroup

Gets details about a Network Connectivity Center group.

Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, name: &str
) -> Result<()> {
    let response = client.get_group()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_groups(&self) -> ListGroups

Lists groups in a given hub.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, parent: &str
) -> Result<()> {
    let mut list = client.list_groups()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn update_group(&self) -> UpdateGroup

Updates the parameters of a Network Connectivity Center group.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_networkconnectivity_v1::model::Group;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService, name: &str
) -> Result<()> {
    let response = client.update_group()
        .set_group(
            Group::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn set_iam_policy(&self) -> SetIamPolicy

Sets the access control policy on the specified resource. Replaces any existing policy.

Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.

Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService
) -> Result<()> {
    let response = client.set_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_iam_policy(&self) -> GetIamPolicy

Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.

Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService
) -> Result<()> {
    let response = client.get_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn test_iam_permissions(&self) -> TestIamPermissions

Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.

Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.

Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService
) -> Result<()> {
    let response = client.test_iam_permissions()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_networkconnectivity_v1::Result;
async fn sample(
   client: &HubService
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}