ConsumerPscConfig

#[non_exhaustive]
pub struct ConsumerPscConfig { pub project: String, pub network: String, pub disable_global_access: bool, pub state: State, pub producer_instance_id: String, pub service_attachment_ip_address_map: HashMap<String, String>, pub consumer_instance_project: String, pub producer_instance_metadata: HashMap<String, String>, pub ip_version: Option<IPVersion>, /* private fields */ }
Allow the producer to specify which consumers can connect to it.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
project: String

The consumer project where PSC connections are allowed to be created in.

network: String

The resource path of the consumer network where PSC connections are allowed to be created in. Note, this network does not need be in the ConsumerPscConfig.project in the case of SharedVPC. Example: projects/{projectNumOrId}/global/networks/{networkId}.

disable_global_access: bool

This is used in PSC consumer ForwardingRule to control whether the PSC endpoint can be accessed from another region.

state: State

Output only. Overall state of PSC Connections management for this consumer psc config.

producer_instance_id: String
👎Deprecated

Immutable. Deprecated. Use producer_instance_metadata instead. An immutable identifier for the producer instance.

service_attachment_ip_address_map: HashMap<String, String>

Output only. A map to store mapping between customer vip and target service attachment. Only service attachment with producer specified ip addresses are stored here.

consumer_instance_project: String

Required. The project ID or project number of the consumer project. This project is the one that the consumer uses to interact with the producer instance. From the perspective of a consumer who’s created a producer instance, this is the project of the producer instance. Format: ‘projects/<project_id_or_number>’ Eg. ‘projects/consumer-project’ or ‘projects/1234’

producer_instance_metadata: HashMap<String, String>

Immutable. An immutable map for the producer instance metadata.

ip_version: Option<IPVersion>

The requested IP version for the PSC connection.

Implementations

Source

impl ConsumerPscConfig

pub fn new() -> Self

pub fn set_project<T: Into<String>>(self, v: T) -> Self

Sets the value of project.

Example
let x = ConsumerPscConfig::new().set_project("example");
pub fn set_network<T: Into<String>>(self, v: T) -> Self

Sets the value of network.

Example
let x = ConsumerPscConfig::new().set_network("example");
pub fn set_disable_global_access<T: Into<bool>>(self, v: T) -> Self

Sets the value of disable_global_access.

Example
let x = ConsumerPscConfig::new().set_disable_global_access(true);
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_networkconnectivity_v1::model::service_connection_map::consumer_psc_config::State;
let x0 = ConsumerPscConfig::new().set_state(State::Valid);
let x1 = ConsumerPscConfig::new().set_state(State::ConnectionPolicyMissing);
let x2 = ConsumerPscConfig::new().set_state(State::PolicyLimitReached);
pub fn set_producer_instance_id<T: Into<String>>(self, v: T) -> Self

👎Deprecated

Sets the value of producer_instance_id.

Example
let x = ConsumerPscConfig::new().set_producer_instance_id("example");
pub fn set_service_attachment_ip_address_map<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of service_attachment_ip_address_map.

Example
let x = ConsumerPscConfig::new().set_service_attachment_ip_address_map([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_consumer_instance_project<T: Into<String>>(self, v: T) -> Self

Sets the value of consumer_instance_project.

Example
let x = ConsumerPscConfig::new().set_consumer_instance_project("example");
pub fn set_producer_instance_metadata<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of producer_instance_metadata.

Example
let x = ConsumerPscConfig::new().set_producer_instance_metadata([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_ip_version<T>(self, v: T) -> Self
where T: Into<IPVersion>,

Sets the value of ip_version.

Example
use google_cloud_networkconnectivity_v1::model::IPVersion;
let x0 = ConsumerPscConfig::new().set_ip_version(IPVersion::Ipv4);
let x1 = ConsumerPscConfig::new().set_ip_version(IPVersion::Ipv6);
pub fn set_or_clear_ip_version<T>(self, v: Option<T>) -> Self
where T: Into<IPVersion>,

Sets or clears the value of ip_version.

Example
use google_cloud_networkconnectivity_v1::model::IPVersion;
let x0 = ConsumerPscConfig::new().set_or_clear_ip_version(Some(IPVersion::Ipv4));
let x1 = ConsumerPscConfig::new().set_or_clear_ip_version(Some(IPVersion::Ipv6));
let x_none = ConsumerPscConfig::new().set_or_clear_ip_version(None::<IPVersion>);