#[non_exhaustive]pub struct CreateHubRequest {
pub parent: String,
pub hub_id: String,
pub hub: Option<Hub>,
pub request_id: String,
/* private fields */
}Expand description
Request for HubService.CreateHub method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource.
hub_id: StringRequired. A unique identifier for the hub.
hub: Option<Hub>Required. The initial values for a new hub.
request_id: StringOptional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server knows to ignore the request if it has already been completed. The server guarantees that a request doesn’t result in creation of duplicate commitments for at least 60 minutes.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check to see whether the original operation was received. If it was, the server ignores the second request. This behavior prevents clients from mistakenly creating duplicate commitments.
The request ID must be a valid UUID, with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateHubRequest
impl CreateHubRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_hub_id<T: Into<String>>(self, v: T) -> Self
pub fn set_hub_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_hub<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_hub<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self