#[non_exhaustive]pub struct CreateInternalRangeRequest {
pub parent: String,
pub internal_range_id: String,
pub internal_range: Option<InternalRange>,
pub request_id: String,
/* private fields */
}Expand description
Request for InternalRangeService.CreateInternalRange
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource’s name of the internal range.
internal_range_id: StringOptional. Resource ID (i.e. ‘foo’ in ‘[…]/projects/p/locations/l/internalRanges/foo’) See https://google.aip.dev/122#resource-id-segments Unique per location.
internal_range: Option<InternalRange>Required. Initial values for a new internal range
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateInternalRangeRequest
impl CreateInternalRangeRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_internal_range_id<T: Into<String>>(self, v: T) -> Self
pub fn set_internal_range_id<T: Into<String>>(self, v: T) -> Self
Sets the value of internal_range_id.
Example
let x = CreateInternalRangeRequest::new().set_internal_range_id("example");Sourcepub fn set_internal_range<T>(self, v: T) -> Selfwhere
T: Into<InternalRange>,
pub fn set_internal_range<T>(self, v: T) -> Selfwhere
T: Into<InternalRange>,
Sets the value of internal_range.
Example
use google_cloud_networkconnectivity_v1::model::InternalRange;
let x = CreateInternalRangeRequest::new().set_internal_range(InternalRange::default()/* use setters */);Sourcepub fn set_or_clear_internal_range<T>(self, v: Option<T>) -> Selfwhere
T: Into<InternalRange>,
pub fn set_or_clear_internal_range<T>(self, v: Option<T>) -> Selfwhere
T: Into<InternalRange>,
Sets or clears the value of internal_range.
Example
use google_cloud_networkconnectivity_v1::model::InternalRange;
let x = CreateInternalRangeRequest::new().set_or_clear_internal_range(Some(InternalRange::default()/* use setters */));
let x = CreateInternalRangeRequest::new().set_or_clear_internal_range(None::<InternalRange>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateInternalRangeRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateInternalRangeRequest
impl Clone for CreateInternalRangeRequest
Sourcefn clone(&self) -> CreateInternalRangeRequest
fn clone(&self) -> CreateInternalRangeRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateInternalRangeRequest
impl Debug for CreateInternalRangeRequest
Sourceimpl Default for CreateInternalRangeRequest
impl Default for CreateInternalRangeRequest
Sourcefn default() -> CreateInternalRangeRequest
fn default() -> CreateInternalRangeRequest
Sourceimpl Message for CreateInternalRangeRequest
impl Message for CreateInternalRangeRequest
impl StructuralPartialEq for CreateInternalRangeRequest