#[non_exhaustive]pub struct CreateSpokeRequest {
pub parent: String,
pub spoke_id: String,
pub spoke: Option<Spoke>,
pub request_id: String,
/* private fields */
}Expand description
The request for HubService.CreateSpoke.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource.
spoke_id: StringRequired. Unique id for the spoke to create.
spoke: Option<Spoke>Required. The initial values for a new spoke.
request_id: StringOptional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server knows to ignore the request if it has already been completed. The server guarantees that a request doesn’t result in creation of duplicate commitments for at least 60 minutes.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check to see whether the original operation was received. If it was, the server ignores the second request. This behavior prevents clients from mistakenly creating duplicate commitments.
The request ID must be a valid UUID, with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateSpokeRequest
impl CreateSpokeRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_spoke_id<T: Into<String>>(self, v: T) -> Self
pub fn set_spoke_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_spoke<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_spoke<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateSpokeRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateSpokeRequest
impl Clone for CreateSpokeRequest
Sourcefn clone(&self) -> CreateSpokeRequest
fn clone(&self) -> CreateSpokeRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateSpokeRequest
impl Debug for CreateSpokeRequest
Sourceimpl Default for CreateSpokeRequest
impl Default for CreateSpokeRequest
Sourcefn default() -> CreateSpokeRequest
fn default() -> CreateSpokeRequest
Sourceimpl Message for CreateSpokeRequest
impl Message for CreateSpokeRequest
Sourceimpl PartialEq for CreateSpokeRequest
impl PartialEq for CreateSpokeRequest
impl StructuralPartialEq for CreateSpokeRequest