#[non_exhaustive]pub struct Destination {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub etag: String,
pub description: String,
pub ip_prefix: String,
pub endpoints: Vec<DestinationEndpoint>,
pub state_timeline: Option<StateTimeline>,
pub uid: String,
/* private fields */
}Expand description
The Destination resource. It specifies the IP prefix and the associated
autonomous system numbers (ASN) that you want to include in a
MulticloudDataTransferConfig resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The name of the Destination resource.
Format:
projects/{project}/locations/{location}/multicloudDataTransferConfigs/{multicloud_data_transfer_config}/destinations/{destination}.
create_time: Option<Timestamp>Output only. Time when the Destination resource was created.
update_time: Option<Timestamp>Output only. Time when the Destination resource was updated.
labels: HashMap<String, String>Optional. User-defined labels.
etag: StringThe etag is computed by the server, and might be sent with update and delete requests so that the client has an up-to-date value before proceeding.
description: StringOptional. A description of this resource.
ip_prefix: StringRequired. Immutable. The IP prefix that represents your workload on another CSP.
endpoints: Vec<DestinationEndpoint>Required. Unordered list. The list of DestinationEndpoint resources
configured for the IP prefix.
state_timeline: Option<StateTimeline>Output only. The timeline of the expected Destination states or the
current rest state. If a state change is expected, the value is ADDING,
DELETING or SUSPENDING, depending on the action specified.
Example:
“state_timeline”: {
“states”: [
{
// The time when the Destination resource will be activated.
“effectiveTime”: “2024-12-01T08:00:00Z”,
“state”: “ADDING”
},
{
// The time when the Destination resource will be suspended.
“effectiveTime”: “2024-12-01T20:00:00Z”,
“state”: “SUSPENDING”
}
]
}
uid: StringOutput only. The Google-generated unique ID for the Destination resource.
This value is unique across all Destination resources.
If a resource is deleted and another with the same name is
created, the new resource is assigned a different and unique ID.
Implementations
Sourceimpl Destination
impl Destination
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Destination::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Destination::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Destination::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Destination::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Destination::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Destination::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_ip_prefix<T: Into<String>>(self, v: T) -> Self
pub fn set_ip_prefix<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_endpoints<T, V>(self, v: T) -> Self
pub fn set_endpoints<T, V>(self, v: T) -> Self
Sourcepub fn set_state_timeline<T>(self, v: T) -> Selfwhere
T: Into<StateTimeline>,
pub fn set_state_timeline<T>(self, v: T) -> Selfwhere
T: Into<StateTimeline>,
Sets the value of state_timeline.
Example
use google_cloud_networkconnectivity_v1::model::StateTimeline;
let x = Destination::new().set_state_timeline(StateTimeline::default()/* use setters */);Sourcepub fn set_or_clear_state_timeline<T>(self, v: Option<T>) -> Selfwhere
T: Into<StateTimeline>,
pub fn set_or_clear_state_timeline<T>(self, v: Option<T>) -> Selfwhere
T: Into<StateTimeline>,
Sets or clears the value of state_timeline.
Example
use google_cloud_networkconnectivity_v1::model::StateTimeline;
let x = Destination::new().set_or_clear_state_timeline(Some(StateTimeline::default()/* use setters */));
let x = Destination::new().set_or_clear_state_timeline(None::<StateTimeline>);Trait Implementations
Sourceimpl Clone for Destination
impl Clone for Destination
Sourcefn clone(&self) -> Destination
fn clone(&self) -> Destination
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for Destination
impl Debug for Destination
Sourceimpl Default for Destination
impl Default for Destination
Sourcefn default() -> Destination
fn default() -> Destination
Sourceimpl Message for Destination
impl Message for Destination
Sourceimpl PartialEq for Destination
impl PartialEq for Destination
impl StructuralPartialEq for Destination