#[non_exhaustive]pub struct LinkedInterconnectAttachments {
pub uris: Vec<String>,
pub site_to_site_data_transfer: bool,
pub vpc_network: String,
pub include_import_ranges: Vec<String>,
/* private fields */
}Expand description
A collection of VLAN attachment resources. These resources should be redundant attachments that all advertise the same prefixes to Google Cloud. Alternatively, in active/passive configurations, all attachments should be capable of advertising the same prefixes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.uris: Vec<String>The URIs of linked interconnect attachment resources
site_to_site_data_transfer: boolA value that controls whether site-to-site data transfer is enabled for these resources. Data transfer is available only in supported locations.
vpc_network: StringOutput only. The VPC network where these VLAN attachments are located.
include_import_ranges: Vec<String>Optional. IP ranges allowed to be included during import from hub (does not control transit connectivity). The only allowed value for now is “ALL_IPV4_RANGES”.
Implementations
Sourceimpl LinkedInterconnectAttachments
impl LinkedInterconnectAttachments
Sourcepub fn set_site_to_site_data_transfer<T: Into<bool>>(self, v: T) -> Self
pub fn set_site_to_site_data_transfer<T: Into<bool>>(self, v: T) -> Self
Sets the value of site_to_site_data_transfer.
Example
let x = LinkedInterconnectAttachments::new().set_site_to_site_data_transfer(true);Sourcepub fn set_vpc_network<T: Into<String>>(self, v: T) -> Self
pub fn set_vpc_network<T: Into<String>>(self, v: T) -> Self
Sets the value of vpc_network.
Example
let x = LinkedInterconnectAttachments::new().set_vpc_network("example");Sourcepub fn set_include_import_ranges<T, V>(self, v: T) -> Self
pub fn set_include_import_ranges<T, V>(self, v: T) -> Self
Sets the value of include_import_ranges.
Example
let x = LinkedInterconnectAttachments::new().set_include_import_ranges(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for LinkedInterconnectAttachments
impl Clone for LinkedInterconnectAttachments
Sourcefn clone(&self) -> LinkedInterconnectAttachments
fn clone(&self) -> LinkedInterconnectAttachments
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for LinkedInterconnectAttachments
impl Default for LinkedInterconnectAttachments
Sourcefn default() -> LinkedInterconnectAttachments
fn default() -> LinkedInterconnectAttachments
impl StructuralPartialEq for LinkedInterconnectAttachments