#[non_exhaustive]pub struct LinkedVpcNetwork {
pub uri: String,
pub exclude_export_ranges: Vec<String>,
pub include_export_ranges: Vec<String>,
pub proposed_include_export_ranges: Vec<String>,
pub proposed_exclude_export_ranges: Vec<String>,
pub producer_vpc_spokes: Vec<String>,
/* private fields */
}Expand description
An existing VPC network.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.uri: StringRequired. The URI of the VPC network resource.
exclude_export_ranges: Vec<String>Optional. IP ranges encompassing the subnets to be excluded from peering.
include_export_ranges: Vec<String>Optional. IP ranges allowed to be included from peering.
proposed_include_export_ranges: Vec<String>Optional. The proposed include export IP ranges waiting for hub administration’s approval.
proposed_exclude_export_ranges: Vec<String>Output only. The proposed exclude export IP ranges waiting for hub administration’s approval.
producer_vpc_spokes: Vec<String>Output only. The list of Producer VPC spokes that this VPC spoke is a service consumer VPC spoke for. These producer VPCs are connected through VPC peering to this spoke’s backing VPC network. Because they are directly connected throuh VPC peering, NCC export filters do not apply between the service consumer VPC spoke and any of its producer VPC spokes. This VPC spoke cannot be deleted as long as any of these producer VPC spokes are connected to the NCC Hub.
Implementations
Sourceimpl LinkedVpcNetwork
impl LinkedVpcNetwork
Sourcepub fn set_exclude_export_ranges<T, V>(self, v: T) -> Self
pub fn set_exclude_export_ranges<T, V>(self, v: T) -> Self
Sets the value of exclude_export_ranges.
Example
let x = LinkedVpcNetwork::new().set_exclude_export_ranges(["a", "b", "c"]);Sourcepub fn set_include_export_ranges<T, V>(self, v: T) -> Self
pub fn set_include_export_ranges<T, V>(self, v: T) -> Self
Sets the value of include_export_ranges.
Example
let x = LinkedVpcNetwork::new().set_include_export_ranges(["a", "b", "c"]);Sourcepub fn set_proposed_include_export_ranges<T, V>(self, v: T) -> Self
pub fn set_proposed_include_export_ranges<T, V>(self, v: T) -> Self
Sets the value of proposed_include_export_ranges.
Example
let x = LinkedVpcNetwork::new().set_proposed_include_export_ranges(["a", "b", "c"]);Sourcepub fn set_proposed_exclude_export_ranges<T, V>(self, v: T) -> Self
pub fn set_proposed_exclude_export_ranges<T, V>(self, v: T) -> Self
Sets the value of proposed_exclude_export_ranges.
Example
let x = LinkedVpcNetwork::new().set_proposed_exclude_export_ranges(["a", "b", "c"]);Sourcepub fn set_producer_vpc_spokes<T, V>(self, v: T) -> Self
pub fn set_producer_vpc_spokes<T, V>(self, v: T) -> Self
Sets the value of producer_vpc_spokes.
Example
let x = LinkedVpcNetwork::new().set_producer_vpc_spokes(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for LinkedVpcNetwork
impl Clone for LinkedVpcNetwork
Sourcefn clone(&self) -> LinkedVpcNetwork
fn clone(&self) -> LinkedVpcNetwork
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for LinkedVpcNetwork
impl Debug for LinkedVpcNetwork
Sourceimpl Default for LinkedVpcNetwork
impl Default for LinkedVpcNetwork
Sourcefn default() -> LinkedVpcNetwork
fn default() -> LinkedVpcNetwork
Sourceimpl Message for LinkedVpcNetwork
impl Message for LinkedVpcNetwork
Sourceimpl PartialEq for LinkedVpcNetwork
impl PartialEq for LinkedVpcNetwork
impl StructuralPartialEq for LinkedVpcNetwork