#[non_exhaustive]pub struct ListMulticloudDataTransferConfigsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
pub return_partial_success: bool,
/* private fields */
}Expand description
Request message to list MulticloudDataTransferConfig resources.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The name of the parent resource.
page_size: i32Optional. The maximum number of results listed per page.
page_token: StringOptional. The page token.
filter: StringOptional. An expression that filters the results listed in the response.
order_by: StringOptional. The sort order of the results.
return_partial_success: boolOptional. If true, allows partial responses for multi-regional aggregated
list requests.
Implementations
Sourceimpl ListMulticloudDataTransferConfigsRequest
impl ListMulticloudDataTransferConfigsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListMulticloudDataTransferConfigsRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_order_by<T: Into<String>>(self, v: T) -> Self
pub fn set_order_by<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_return_partial_success<T: Into<bool>>(self, v: T) -> Self
pub fn set_return_partial_success<T: Into<bool>>(self, v: T) -> Self
Sets the value of return_partial_success.
Example
ⓘ
let x = ListMulticloudDataTransferConfigsRequest::new().set_return_partial_success(true);Trait Implementations
Sourceimpl Clone for ListMulticloudDataTransferConfigsRequest
impl Clone for ListMulticloudDataTransferConfigsRequest
Sourcefn clone(&self) -> ListMulticloudDataTransferConfigsRequest
fn clone(&self) -> ListMulticloudDataTransferConfigsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListMulticloudDataTransferConfigsRequest
impl Default for ListMulticloudDataTransferConfigsRequest
Sourcefn default() -> ListMulticloudDataTransferConfigsRequest
fn default() -> ListMulticloudDataTransferConfigsRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListMulticloudDataTransferConfigsRequest
impl PartialEq for ListMulticloudDataTransferConfigsRequest
Sourcefn eq(&self, other: &ListMulticloudDataTransferConfigsRequest) -> bool
fn eq(&self, other: &ListMulticloudDataTransferConfigsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListMulticloudDataTransferConfigsRequest