#[non_exhaustive]pub struct ListMulticloudDataTransferSupportedServicesResponse {
pub multicloud_data_transfer_supported_services: Vec<MulticloudDataTransferSupportedService>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message to list the services in your project in regions that are eligible for Data Transfer Essentials configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.multicloud_data_transfer_supported_services: Vec<MulticloudDataTransferSupportedService>The list of supported services.
next_page_token: StringThe next page token.
Implementations
Sourceimpl ListMulticloudDataTransferSupportedServicesResponse
impl ListMulticloudDataTransferSupportedServicesResponse
pub fn new() -> Self
Sourcepub fn set_multicloud_data_transfer_supported_services<T, V>(self, v: T) -> Self
pub fn set_multicloud_data_transfer_supported_services<T, V>(self, v: T) -> Self
Sets the value of multicloud_data_transfer_supported_services.
Example
ⓘ
use google_cloud_networkconnectivity_v1::model::MulticloudDataTransferSupportedService;
let x = ListMulticloudDataTransferSupportedServicesResponse::new()
.set_multicloud_data_transfer_supported_services([
MulticloudDataTransferSupportedService::default()/* use setters */,
MulticloudDataTransferSupportedService::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListMulticloudDataTransferSupportedServicesResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListMulticloudDataTransferSupportedServicesResponse
impl Clone for ListMulticloudDataTransferSupportedServicesResponse
Sourcefn clone(&self) -> ListMulticloudDataTransferSupportedServicesResponse
fn clone(&self) -> ListMulticloudDataTransferSupportedServicesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListMulticloudDataTransferSupportedServicesResponse
impl Default for ListMulticloudDataTransferSupportedServicesResponse
Sourcefn default() -> ListMulticloudDataTransferSupportedServicesResponse
fn default() -> ListMulticloudDataTransferSupportedServicesResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListMulticloudDataTransferSupportedServicesResponse
impl PartialEq for ListMulticloudDataTransferSupportedServicesResponse
Sourcefn eq(
&self,
other: &ListMulticloudDataTransferSupportedServicesResponse,
) -> bool
fn eq( &self, other: &ListMulticloudDataTransferSupportedServicesResponse, ) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListMulticloudDataTransferSupportedServicesResponse