#[non_exhaustive]pub struct MulticloudDataTransferConfig {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub etag: String,
pub description: String,
pub destinations_count: i32,
pub destinations_active_count: i32,
pub services: HashMap<String, StateTimeline>,
pub uid: String,
/* private fields */
}Expand description
The MulticloudDataTransferConfig resource. It lists the services that you
configure for Data Transfer Essentials billing and metering.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The name of the MulticloudDataTransferConfig resource.
Format:
projects/{project}/locations/{location}/multicloudDataTransferConfigs/{multicloud_data_transfer_config}.
create_time: Option<Timestamp>Output only. Time when the MulticloudDataTransferConfig resource was
created.
update_time: Option<Timestamp>Output only. Time when the MulticloudDataTransferConfig resource was
updated.
labels: HashMap<String, String>Optional. User-defined labels.
etag: StringThe etag is computed by the server, and might be sent with update and delete requests so that the client has an up-to-date value before proceeding.
description: StringOptional. A description of this resource.
destinations_count: i32Output only. The number of Destination resources configured for the
MulticloudDataTransferConfig resource.
destinations_active_count: i32Output only. The number of Destination resources in use with the
MulticloudDataTransferConfig resource.
services: HashMap<String, StateTimeline>Optional. Maps services to their current or planned states. Service names
are keys, and the associated values describe the state of the service. If a
state change is expected, the value is either ADDING or DELETING,
depending on the actions taken.
Sample output: “services”: { “big-query”: { “states”: [ { “effectiveTime”: “2024-12-12T08:00:00Z” “state”: “ADDING”, }, ] }, “cloud-storage”: { “states”: [ { “state”: “ACTIVE”, } ] } }
uid: StringOutput only. The Google-generated unique ID for the
MulticloudDataTransferConfig resource. This value is unique across all
MulticloudDataTransferConfig resources. If a resource is deleted and
another with the same name is created, the new resource is assigned a
different and unique ID.
Implementations
Sourceimpl MulticloudDataTransferConfig
impl MulticloudDataTransferConfig
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = MulticloudDataTransferConfig::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = MulticloudDataTransferConfig::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = MulticloudDataTransferConfig::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = MulticloudDataTransferConfig::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = MulticloudDataTransferConfig::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = MulticloudDataTransferConfig::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = MulticloudDataTransferConfig::new().set_description("example");Sourcepub fn set_destinations_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_destinations_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of destinations_count.
Example
let x = MulticloudDataTransferConfig::new().set_destinations_count(42);Sourcepub fn set_destinations_active_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_destinations_active_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of destinations_active_count.
Example
let x = MulticloudDataTransferConfig::new().set_destinations_active_count(42);Sourcepub fn set_services<T, K, V>(self, v: T) -> Self
pub fn set_services<T, K, V>(self, v: T) -> Self