#[non_exhaustive]pub struct RouteTable {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub description: String,
pub uid: String,
pub state: State,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringImmutable. The name of the route table. Route table names must be unique.
They use the following form:
projects/{project_number}/locations/global/hubs/{hub}/routeTables/{route_table_id}
create_time: Option<Timestamp>Output only. The time the route table was created.
update_time: Option<Timestamp>Output only. The time the route table was last updated.
labels: HashMap<String, String>Optional labels in key-value pair format. For more information about labels, see Requirements for labels.
description: StringAn optional description of the route table.
uid: StringOutput only. The Google-generated UUID for the route table. This value is
unique across all route table resources. If a route table is deleted and
another with the same name is created, the new route table is assigned
a different uid.
state: StateOutput only. The current lifecycle state of this route table.
Implementations
Sourceimpl RouteTable
impl RouteTable
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = RouteTable::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = RouteTable::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = RouteTable::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = RouteTable::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = RouteTable::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = RouteTable::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self