#[non_exhaustive]pub struct UpdateDestinationRequest {
pub update_mask: Option<FieldMask>,
pub destination: Option<Destination>,
pub request_id: String,
/* private fields */
}Expand description
Request message to update a Destination resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Optional. FieldMask is used to specify the fields to be overwritten in the Destinationresource by the update. The fields specified inupdate_mask` are relative to the resource, not
the full request. A field is overwritten if it is in the mask. If you
don’t specify a mask, all fields are overwritten.
destination: Option<Destination>Required. The Destination resource to update.
request_id: StringOptional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server can ignore the request if it has already been completed. The server waits for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, can ignore the second request.
The request ID must be a valid UUID with the exception that zero UUID (00000000-0000-0000-0000-000000000000) isn’t supported.
Implementations
Sourceimpl UpdateDestinationRequest
impl UpdateDestinationRequest
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateDestinationRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateDestinationRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateDestinationRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_destination<T>(self, v: T) -> Selfwhere
T: Into<Destination>,
pub fn set_destination<T>(self, v: T) -> Selfwhere
T: Into<Destination>,
Sets the value of destination.
Example
use google_cloud_networkconnectivity_v1::model::Destination;
let x = UpdateDestinationRequest::new().set_destination(Destination::default()/* use setters */);Sourcepub fn set_or_clear_destination<T>(self, v: Option<T>) -> Selfwhere
T: Into<Destination>,
pub fn set_or_clear_destination<T>(self, v: Option<T>) -> Selfwhere
T: Into<Destination>,
Sets or clears the value of destination.
Example
use google_cloud_networkconnectivity_v1::model::Destination;
let x = UpdateDestinationRequest::new().set_or_clear_destination(Some(Destination::default()/* use setters */));
let x = UpdateDestinationRequest::new().set_or_clear_destination(None::<Destination>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = UpdateDestinationRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for UpdateDestinationRequest
impl Clone for UpdateDestinationRequest
Sourcefn clone(&self) -> UpdateDestinationRequest
fn clone(&self) -> UpdateDestinationRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for UpdateDestinationRequest
impl Debug for UpdateDestinationRequest
Sourceimpl Default for UpdateDestinationRequest
impl Default for UpdateDestinationRequest
Sourcefn default() -> UpdateDestinationRequest
fn default() -> UpdateDestinationRequest
Sourceimpl Message for UpdateDestinationRequest
impl Message for UpdateDestinationRequest
Sourceimpl PartialEq for UpdateDestinationRequest
impl PartialEq for UpdateDestinationRequest
impl StructuralPartialEq for UpdateDestinationRequest